@@ -1,25 +1,16 @@
+package App::ClusterSSH::Cluster;
+
 use strict;
 use warnings;
 
-package App::ClusterSSH::Cluster;
-$App::ClusterSSH::Cluster::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Cluster::VERSION = '4.1806';
-# ABSTRACT: App::ClusterSSH::Cluster - Object representing cluster configuration
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-Object representing application configuration
-
-=cut
+use version;
+our $VERSION = version->new('0.01');
 
 use Carp;
-use Try::Tiny 0.28;
+use Try::Tiny;
 use English qw( -no_match_vars );
 
 use base qw/ App::ClusterSSH::Base /;
-use App::ClusterSSH::Range;
 
 our $master_object_ref;
 
@@ -88,7 +79,7 @@ sub _run_external_clusters {
 
     $self->debug( 3, 'Running tags through external command' );
     $self->debug( 4, 'External command: ', $external_command );
-    $self->debug( 3, 'Args ',              join( ',', @args ) );
+    $self->debug( 3, 'Args ', join( ',', @args ) );
 
     my $command = "$external_command @args";
 
@@ -229,18 +220,20 @@ sub expand_glob {
     my ( $self, $type, $name, @items ) = @_;
 
     my @expanded;
-    my $range = App::ClusterSSH::Range->new();
 
     # skip expanding anything that appears to have nasty metachars
     if ( !grep {m/[\`\!\$;]/} @items ) {
+        if ( grep {m/[{]/} @items ) {
 
-        $self->debug( 4, "Non-expanded: @items" );
-
-        @items = $range->expand(@items);
-
-     # run glob over anything left incase there are numeric and textual ranges
-        @expanded = map { glob $_ } @items;
-        $self->debug( 4, "Final expansion: @expanded" );
+      #@expanded = split / /, `/bin/bash -c 'shopt -s extglob\n echo @items'`;
+            my $cmd = $self->parent->config->{shell_expansion};
+            $cmd =~ s/%items%/@items/;
+            @expanded = split / /, `$cmd`;
+            chomp(@expanded);
+        }
+        else {
+            @expanded = map { glob $_ } @items;
+        }
     }
     else {
         warn(
@@ -295,6 +288,18 @@ sub dump_tags {
 
 1;
 
+=pod
+
+=head1 NAME
+
+App::ClusterSSH::Cluster - Object representing cluster configuration
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+Object representing application configuration
+
 =head1 METHODS
 
 =over 4
@@ -361,3 +366,21 @@ Returns a hash of all tag data.
 Use shell expansion against each item in @items, where $type is either 'node', or 'tag' and $name is the node or tag name.  These attributes are presented to the user in the event of an issue with the expanion to track down the source.
 
 =back
+
+=head1 AUTHOR
+
+Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 1999-2015 Duncan Ferguson.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
+
+1;
