@@ -1,18 +1,10 @@
+package App::ClusterSSH::Config;
+
 use strict;
 use warnings;
 
-package App::ClusterSSH::Config;
-$App::ClusterSSH::Config::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Config::VERSION = '4.1806';
-# ABSTRACT: ClusterSSH::Config - Object representing application configuration
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-Object representing application configuration
-
-=cut
+use version;
+our $VERSION = version->new('0.02');
 
 use Carp;
 use Try::Tiny;
@@ -38,7 +30,6 @@ my %default_config = (
     terminal_bg_style          => 'dark',
     terminal_allow_send_events => "-xrm '*.VT100.allowSendEvents:true'",
     terminal_font              => "6x13",
-    main_window_font           => "",
     terminal_size              => "80x24",
 
     use_hotkeys             => "yes",
@@ -51,15 +42,10 @@ my %default_config = (
     key_macros_enable       => "Alt-p",
     key_paste               => "Control-v",
     key_username            => "Alt-u",
-    key_user_1              => "Alt-1",
-    key_user_2              => "Alt-2",
-    key_user_3              => "Alt-3",
-    key_user_4              => "Alt-4",
     mouse_paste             => "Button-2",
     auto_quit               => "yes",
     auto_close              => 5,
     use_natural_sort        => 0,
-    preserve_host_order     => 0,
     window_tiling           => "yes",
     window_tiling_direction => "right",
     console_position        => "",
@@ -91,8 +77,6 @@ my %default_config = (
     extra_tag_file           => '',
     extra_cluster_file       => '',
     external_cluster_command => '',
-    external_command_mode    => '0600',
-    external_command_pipe    => '',
 
     unmap_on_redraw => "no",    # Debian #329440
 
@@ -101,9 +85,6 @@ my %default_config = (
     history_height => 10,
 
     command             => q{},
-    command_pre         => q{},
-    command_post        => q{},
-    hide_menu           => 0,
     max_host_menu_items => 30,
 
     macros_enabled   => 'yes',
@@ -112,35 +93,19 @@ my %default_config = (
     macro_username   => '%u',
     macro_newline    => '%n',
     macro_version    => '%v',
-    macro_user_1     => '%1',
-    macro_user_2     => '%2',
-    macro_user_3     => '%3',
-    macro_user_4     => '%4',
-
-    macro_user_1_command => '',
-    macro_user_2_command => '',
-    macro_user_3_command => '',
-    macro_user_4_command => '',
-    hostname_override    => '',
 
     max_addhost_menu_cluster_items => 6,
     menu_send_autotearoff          => 0,
     menu_host_autotearoff          => 0,
 
-    unique_servers    => 0,
     use_all_a_records => 0,
 
     send_menu_xml_file => $ENV{HOME} . '/.clusterssh/send_menu',
 
-    auto_wm_decoration_offsets => "no",    # Debian #842965
+    shell_expansion => "/bin/bash -c 'shopt -s extglob\n echo %items%'",
 
     # don't set username here as takes precendence over ssh config
     user => '',
-    rows => -1,
-    cols => -1,
-
-    fillscreen => "no",
-
 );
 
 sub new {
@@ -296,19 +261,8 @@ sub parse_config_file {
     # tidy up entries, just in case
     $read_config{terminal_font} =~ s/['"]//g
         if ( $read_config{terminal_font} );
-    $read_config{main_window_font} =~ s/['"]//g
-        if ( $read_config{main_window_font} );
 
     $self->validate_args(%read_config);
-
-    # Look at the user macros and if not set remove the hotkey for them
-    for my $i (qw/ 1 2 3 4 /) {
-        if ( !$self->{"macro_user_${i}_command"} ) {
-            delete $self->{"key_user_${i}"};
-        }
-    }
-
-    return $self;
 }
 
 sub load_configs {
@@ -320,7 +274,7 @@ sub load_configs {
         $ENV{HOME} . '/.clusterssh/config',
         )
     {
-        $self->parse_config_file($config) if ( -e $config && !-d _ );
+        $self->parse_config_file($config) if ( -e $config );
     }
 
     # write out default config file if necesasry
@@ -335,22 +289,10 @@ sub load_configs {
     # relative to config directory
     for my $config (@configs) {
         next unless ($config);    # can be null when passed from Getopt::Long
-        $self->parse_config_file($config) if ( -e $config && !-d _ );
+        $self->parse_config_file($config) if ( -e $config );
 
         my $file = $ENV{HOME} . '/.clusterssh/config_' . $config;
-        $self->parse_config_file($file) if ( -e $file && !-d _ );
-    }
-
-    # Override confuration via environment variable using cssh_ prefix
-    #  eg: terminal_size => cssh_terminal_size
-    foreach my $config_key ( sort( keys(%default_config) ) ) {
-        my $env_config_key = "cssh_" . $config_key;
-        if ( exists $ENV{ uc($env_config_key) } ) {
-            $env_config_key = uc($env_config_key);
-        }
-        if ( exists $ENV{$env_config_key} ) {
-            $self->{$config_key} = $ENV{$env_config_key};
-        }
+        $self->parse_config_file($file) if ( -e $file );
     }
 
     return $self;
@@ -549,7 +491,7 @@ sub dump {
     my ( $self, $no_exit, ) = @_;
 
     $self->debug( 3, 'Dumping config to STDOUT' );
-    print( '# Configuration dump produced by "cssh -d"', $/ );
+    print( '# Configuration dump produced by "cssh -u"', $/ );
 
     foreach my $key ( sort keys %$self ) {
         my $comment = '';
@@ -575,6 +517,18 @@ sub dump {
 
 1;
 
+=pod
+
+=head1 NAME
+
+ClusterSSH::Config - Object representing application configuration
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+Object representing application configuration
+
 =head1 METHODS
 
 =over 4
@@ -615,3 +569,21 @@ are loaded).
 Write currently defined configuration to STDOUT
 
 =back
+
+=head1 AUTHOR
+
+Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 1999-2015 Duncan Ferguson.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
+
+1;
