@@ -1,23 +1,15 @@
+package App::ClusterSSH::Getopt;
+
 use strict;
 use warnings;
 
-package App::ClusterSSH::Getopt;
-$App::ClusterSSH::Getopt::VERSION = '4.18_06'; # TRIAL
-$App::ClusterSSH::Getopt::VERSION = '4.1806';
-# ABSTRACT: App::ClusterSSH::Getopt - module to process command line args
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-Object representing application configuration
-
-=cut
+use version;
+our $VERSION = version->new('0.01');
 
 use Carp;
 use Try::Tiny;
 use Pod::Usage;
-use Getopt::Long 2.48 qw(:config no_ignore_case bundling no_auto_abbrev);
+use Getopt::Long qw(:config no_ignore_case bundling no_auto_abbrev);
 use FindBin qw($Script);
 
 use base qw/ App::ClusterSSH::Base /;
@@ -26,7 +18,7 @@ sub new {
     my ( $class, %args ) = @_;
 
     # basic setup that is over-rideable by each script as needs may be
-    # different depending on the command used
+    # different depending ont he command used
     my %setup = (
         usage => [
             '-h|--help', '[options] [[user@]<server>[:port]|<tag>] [...] ',
@@ -96,7 +88,7 @@ sub add_option {
         }
         $desc  .= " $arg" if ($arg);
         $short .= " $arg" if ( $short && $arg );
-        $long  .= " $arg" if ( $long  && $arg );
+        $long  .= " $arg" if ( $long && $arg );
     }
     $args{option_desc}  = $desc;
     $args{option_short} = $short;
@@ -134,7 +126,7 @@ sub add_common_options {
     $self->add_option(
         spec => 'debug:+',
         help => $self->loc(
-            "Enable debugging.  Either a level can be provided or the option can be repeated multiple times.  Maximum level is 9."
+            "Enable debugging.  Either a level can be provided or the option can be repeated multiple times.  Maximum level is 4."
         ),
         default => 0,
     );
@@ -150,16 +142,10 @@ sub add_common_options {
             'Number of seconds to wait before closing finished terminal windows.'
         ),
     );
-    $self->add_option(
-        spec => 'no-autoclose',
-        help => $self->loc(
-            'Do not close terminal windows automatically (same as auto_close = 0).'
-        ),
-    );
     $self->add_option(
         spec => 'autoquit|q',
         help => $self->loc(
-            'Toggle automatically quitting after the last client window has closed (overriding the config file).'
+            'Toggle automatically quiting after the last client window has closed (overriding the config file).'
         ),
     );
     $self->add_option(
@@ -197,13 +183,6 @@ sub add_common_options {
             'Specify the font to use in the terminal windows. Use standard X font notation such as "5x8".'
         ),
     );
-    $self->add_option(
-        spec     => 'main-window-font|M=s',
-        arg_desc => 'font',
-        help     => $self->loc(
-            'Specify the font to use in the main console window. Use Tk font notation such as "sans 14 bold".'
-        ),
-    );
     $self->add_option(
         spec => 'list|L:s',
         help => $self->loc(
@@ -250,12 +229,6 @@ sub add_common_options {
             'Toggle connecting to each host only once when a hostname has been specified multiple times.'
         ),
     );
-    $self->add_option(
-        spec => 'preserve-host-order|P',
-        help => $self->loc(
-            'Display and tile hosts in the order given on the command line instead of alphabetically.'
-        ),
-    );
     $self->add_option(
         spec => 'use-all-a-records|A',
         help => $self->loc(
@@ -267,22 +240,6 @@ sub add_common_options {
         help =>
             $self->loc('Do not output extra text when using some options'),
     );
-    $self->add_option(
-        spec     => 'cols|x=i',
-        arg_desc => 'cols',
-        help     => $self->loc('Number of columns'),
-    );
-    $self->add_option(
-        spec     => 'rows|y=i',
-        arg_desc => 'rows',
-        help     => $self->loc('Number of rows'),
-    );
-
-    $self->add_option(
-        spec => 'fillscreen',
-        help => $self->loc(
-            'Resize terminal windows to fill the whole available screen'),
-    );
 
     return $self;
 }
@@ -349,14 +306,10 @@ sub getopts {
     }
 
     $options->{debug} ||= 0;
-    $options->{debug} = 9 if ( $options->{debug} && $options->{debug} > 9 );
+    $options->{debug} = 4 if ( $options->{debug} && $options->{debug} > 4 );
 
     # Now all options are set to the correct values, generate accessor methods
     foreach my $option ( sort keys( %{ $self->{command_options} } ) ) {
-
-        # skip some accessors as they are already defined elsewhere
-        next if $option =~ m/^(debug)\W/;
-
         my $accessor = $self->{command_options}->{$option}->{accessor};
 
         my $default = $self->{command_options}->{$option}->{default};
@@ -380,7 +333,7 @@ sub getopts {
         }
     }
 
-    $self->set_debug_level( $options->{debug} );
+    $self->set_debug_level( $self->debug );
 
     $self->parent->config->load_configs( $self->config_file );
 
@@ -394,11 +347,6 @@ sub getopts {
             = !$self->parent->config->{unique_servers} || 0;
     }
 
-    if ( $self->preserve_host_order ) {
-        $self->parent->config->{preserve_host_order}
-            = !$self->parent->config->{preserve_host_order} || 0;
-    }
-
     $self->parent->config->{title} = $self->title if ( $self->title );
     $self->parent->config->{port}  = $self->port  if ( $self->port );
 
@@ -410,8 +358,6 @@ sub getopts {
         if ( $self->can('username') && $self->username );
 
     $self->parent->config->{terminal_font} = $self->font if ( $self->font );
-    $self->parent->config->{main_window_font} = $self->main_window_font
-        if ( $self->main_window_font );
     $self->parent->config->{terminal_args} = $self->term_args
         if ( $self->term_args );
 
@@ -420,8 +366,6 @@ sub getopts {
     $self->parent->config->{auto_close} = $self->autoclose
         if ( $self->autoclose );
 
-    $self->parent->config->{auto_close} = 0 if ( $self->no_autoclose );
-
     if ( $self->autoquit ) {
         $self->parent->config->{auto_quit}
             = !$self->parent->config->{auto_quit} || 0;
@@ -432,14 +376,6 @@ sub getopts {
             = !$self->parent->config->{window_tiling} || 0;
     }
 
-    if ( $self->rows ) {
-        $self->parent->config->{rows} = $self->rows;
-    }
-    if ( $self->cols ) {
-        $self->parent->config->{cols} = $self->cols;
-    }
-    $self->parent->config->{fillscreen} = "yes"
-        if ( $self->fillscreen );
     return $self;
 }
 
@@ -455,13 +391,10 @@ sub output {
 sub _generate_pod {
     my ($self) = @_;
 
-    output $/,           "=pod";
+    output $/ , "=pod";
     output '=head1 ',    $self->loc('NAME');
     output "$Script - ", $self->loc("Cluster administration tool");
-    output '=head1 ',    $self->loc('VERSION');
-    output $self->loc( "This documentation is for version: [_1]",
-        $self->parent->VERSION );
-    output '=head1 ', $self->loc('SYNOPSIS');
+    output '=head1 ',    $self->loc('SYNOPSIS');
 
     # build the synopsis
     print "$Script ";
@@ -475,28 +408,6 @@ sub _generate_pod {
     }
     print $/, $/;
 
-    output '=head1 ', $self->loc('RELATED');
-    output $self->loc(
-        q{Also see the individual man pages for each of these utilities});
-
-    my %utils = (
-        ctel  => 'telnet',
-        cssh  => 'ssh',
-        crsh  => 'rsh',
-        csftp => 'sftp',
-        ccon  => 'console',
-    );
-
-    output '=over';
-
-    for my $util ( sort grep { !/$Script/ } keys %utils ) {
-        output "=item $util - "
-            . $self->loc( q{Use '[_1]' as the communication method},
-            $utils{$util} );
-    }
-
-    output '=back';
-
     output '=head1 ', $self->loc('DESCRIPTION');
     output $self->loc(
         q{The command opens an administration console and an xterm to all specified hosts.  Any text typed into the administration console is replicated to all windows.  All windows may also be typed into directly.
@@ -602,7 +513,7 @@ would replace the <Alt-n> with the client's name in each window.}
     );
     output '=item ', $self->parent->config->{key_localname};
     output $self->loc(
-        q{Paste in the hostname of the server cssh is being run on});
+        q{Paste in the hostname of the server cssh is ebing run on});
     output '=item ', $self->parent->config->{key_quit};
     output $self->loc(
         'Quit the program and close all connections and windows.');
@@ -610,14 +521,6 @@ would replace the <Alt-n> with the client's name in each window.}
     output $self->loc(q{Retile all the client windows.});
     output '=item ', $self->parent->config->{key_username};
     output $self->loc(q{Paste in the username for the connection});
-    output '=item ', $self->parent->config->{key_user_1} || 'Alt-1';
-    output '=item ', $self->parent->config->{key_user_2} || 'Alt-2';
-    output '=item ', $self->parent->config->{key_user_3} || 'Alt-3';
-    output '=item ', $self->parent->config->{key_user_4} || 'Alt-4';
-    output $self->loc(
-        q{Run the matching user defined macro on the server and send the output to the client}
-    );
-
     output '=back';
 
     output '=head1 ' . $self->loc('EXAMPLES');
@@ -660,7 +563,7 @@ would replace the <Alt-n> with the client's name in each window.}
     output $self->loc(
         q{All comments (marked by a #) and blank lines are ignored.  Tags may be nested, but be aware of using recursive tags as they are not checked for.}
     );
-    output $self->loc(q{Servers can be defined using expansion macros:});
+    output $self->loc(q{Servers can be defined using bash shell expansion:});
     output 'C<< webservers websvr{a,b,c} >>';
     output $self->loc(q{would be expanded to});
     output 'C<< webservers websvra websvrb websvrc >>';
@@ -668,7 +571,10 @@ would replace the <Alt-n> with the client's name in each window.}
     output 'C<< webservers websvr{6..9} >>';
     output $self->loc(q{would be expanded to});
     output 'C<< webservers websvr6 websvr7 websvr8 websvr9 >>';
-
+    output $self->loc(
+        q{B<NOTE:> this requires [_1] to be installed on your system (see [_2] configuration option },
+        '/bin/bash', 'C<shell_expansion>'
+    );
     output $self->loc(
         q{Extra cluster files may also be specified either as an option on the command line (see [_1]) or in the user's [_2] file (see [_3] configuration option).},
         'C<cluster-file>',
@@ -726,23 +632,6 @@ would replace the <Alt-n> with the client's name in each window.}
         'L<--autoquit>',
     );
 
-    output '=item auto_wm_decoration_offsets = no';
-    output $self->loc(
-        'Enable or disable alternative algorithm for calculating terminal positioning.',
-    );
-
-    output '=item command_pre =';
-    output '=item command_post =';
-    output $self->loc(
-        q{Add extra commands around the communication method.  For example:
-
-command_pre= . $HOME/virtualenvs/default/bin/active ;
-command_post= | ct
-
-would allow for using Python virtual envronments and then piping all shell output through C<chromaterm> for syntax highlighting.  Note: you must use appropriate command separators/terminators to keep the meaning of the command pipline (such as C<;> and C<|> between commands).
-
-These are not put through macro parsing.}
-    );
     output '=item comms = ' . $self->parent->config->{comms};
     output $self->loc(
         'Sets the default communication method (initially taken from the name of the program, but can be overridden here).'
@@ -753,22 +642,6 @@ These are not put through macro parsing.}
         q{Set the initial position of the console - if empty then let the window manager decide.  Format is '+<x>+<y>', i.e. '+0+0' is top left hand corner of the screen, '+0-70' is bottom left hand side of screen (more or less).}
     );
 
-    output '=item external_command_mode = 0600';
-    output $self->loc(q{File mode bits for the external_command_pipe.});
-
-    output '=item external_command_pipe = <null>';
-    output $self->loc(
-        q{Define the full path to an external command pipe that can be written to for controlling some aspects of ClusterSSH, such as opening sessions to more clusters.
-
-Commands:
-
-C<< open <tag|hostname> >> - open new sessions to provided tag or hostname
-
-C<< retile >> - force window retiling
-
-e.g.: C<< echo 'open localhost' >> /path/to/external_command_pipe >>}
-    );
-
     output '=item external_cluster_command = <null>';
     output $self->loc(
         q{Define the full path to an external command that can be used to resolve tags to host names.  This command can be written in any language.  The script must accept a list of tags to resolve and output a list of hosts (space separated on a single line).  Any tags that cannot be resolved should be returned unchanged.
@@ -798,11 +671,6 @@ If the external command is given a C<-L> option it should output a list of tags
         'L<KEY SHORTCUTS>'
     );
 
-    output '=item hide_menu = 0';
-    output $self->loc(
-        q{If set to 1, hide the menu bar (File, Hosts, Send, Help) in the console.},
-    );
-
     output '=item key_clientname = Alt-n';
     output $self->loc(
         q{Default key sequence to send cssh client names to client.  See [_1] for more information.},
@@ -839,64 +707,15 @@ If the external command is given a C<-L> option it should output a list of tags
         'L<KEY SHORTCUTS>'
     );
 
-    output '=item key_user_1 = Alt-1';
-    output '=item key_user_2 = Alt-2';
-    output '=item key_user_3 = Alt-3';
-    output '=item key_user_4 = Alt-4';
-    output $self->loc(
-        q{Default key sequence to send user defined macros to client.  If the matching [_2] macro is undefined, the sequence is passed straight to the terminal.  See [_1] for more information.},
-        'L<KEY SHORTCUTS>',
-        'L<macro_user_1>'
-    );
-
     output '=item macro_servername = %s';
     output '=item macro_hostname = %h';
     output '=item macro_username = %u';
     output '=item macro_newline = %n';
     output '=item macro_version = %v';
-    output '=item macro_user_1 = %1';
-    output '=item macro_user_2 = %2';
-    output '=item macro_user_3 = %3';
-    output '=item macro_user_4 = %4';
     output $self->loc(
         q{Change the replacement macro used when either using a 'Send' menu item, or when pasting text into the main console.}
     );
 
-    output '=item macro_user_1_command =';
-    output '=item macro_user_2_command =';
-    output '=item macro_user_3_command =';
-    output '=item macro_user_4_command =';
-
-    output $self->loc(
-        q{User defined macros - the macro is run through the shell on the server and the output is sent to the client.  For example,},
-    );
-
-    output "C<macro_user_1_command=echo echo macro_user_1>";
-    output $self->loc(
-        q{
-            would send the text [_1] into the terminal session.
-        },
-        'C<echo macro_user_1>'
-    );
-    output "C<macro_user_1_command=env | grep CSSH>";
-    output $self->loc(
-        q{
-            would send the CSSH environment variables to the client.
-        },
-    );
-
-    output $self->loc(
-        "The following environment variables are set in the shell of the macro process"
-    );
-    output '=over';
-    output '=item C<CSSH_SERVERNAME>';
-    output '=item C<CSSH_HOSTNAME>';
-    output '=item C<CSSH_USERNAME>';
-    output '=item C<CSSH_CONNECTION_STRING>';
-    output '=item C<CSSH_CONNECTION_PORT>';
-    output '=item C<CSSH_VERSION>';
-    output '=back';
-
     output '=item macros_enabled = yes';
     output $self->loc(
         q{Enable or disable macro replacement.  Note: this affects all the [_1] variables above.},
@@ -953,6 +772,13 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
         q{Number of pixels from the screen's side to reserve when calculating screen geometry for tiling.  Setting this to something like 50 will help keep cssh from positioning windows over your window manager's menu bar if it draws one at that side of the screen.}
     );
 
+    output
+        q{=item shell_expansion = /bin/bash -c 'shopt -s extglob\n echo %items%'"};
+    output $self->loc(
+        q{Command used to expand a given string (provided by the macro [_1]) - used for expanding host names when a [_2] is in the name.  See [_3]},
+        'C<%items%>', 'C<{>', 'L<bash/EXPANSION>'
+    );
+
     output '=item terminal = /path/to/xterm';
     output $self->loc(q{Path to the X-Windows terminal used for the client.});
 
@@ -979,11 +805,6 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
         q{Font to use in the terminal windows.  Use standard X font notation.}
     );
 
-    output '=item main_window_font = ""';
-    output $self->loc(
-        q{Font to use in the main console window.  Use Tk font notation (e.g. "sans 14 bold").  When empty, the default is used (on 4K+ displays, Nimbus 14).}
-    );
-
     output '=item terminal_reserve_top = 5';
     output '=item terminal_reserve_bottom = 0';
     output '=item terminal_reserve_left = 5';
@@ -1043,12 +864,6 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
         'C<1>', 'L<Sort::Naturally>'
     );
 
-    output '=item preserve_host_order = 0';
-    output $self->loc(
-        q{When set to [_1], display and tile hosts in the order given on the command line instead of sorting them alphabetically.  See also [_2].},
-        'C<1>', 'C<-P/--preserve-host-order>'
-    );
-
     output '=item user = $LOGNAME';
     output $self->loc(
         q{Sets the default user for running commands on clients.});
@@ -1152,8 +967,9 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
     );
     output '=back';
 
-    output '=head1 ', $self->loc('TROUBLESHOOTING');
-
+    output '=head1 ', $self->loc('REPORTING BUGS');
+    output '=over';
+    output '=item *';
     output $self->loc(
         q{If you have issues running [_1], first try:
 
@@ -1174,16 +990,16 @@ This performs two tests to confirm cssh is able to work properly with the settin
         $self->parent->config->{comms} );
     output '=back';
 
-    output $self->loc(q{Configuration options to watch for in ssh are:});
+    output $self->loc(q{Configuration options to watch for in ssh are});
     output '=over';
-    output '=item *';
-    output $self->loc(
+    output '=item ',
+        $self->loc(
         q{SSH doesn't understand [_1] - remove the option from the [_2] file},
         'C<-o ConnectTimeout=10>',
         'F<$HOME/.clusterssh/config>'
-    );
-    output '=item *';
-    output $self->loc(
+        );
+    output '=item ',
+        $self->loc(
         q{OpenSSH-3.8 using untrusted ssh tunnels - use [_1] instead of [_2] or use [_3] in [_4] (if you change the default ssh options from [_5] to [_6])},
         'C<-Y>',
         'C<-X>',
@@ -1191,19 +1007,12 @@ This performs two tests to confirm cssh is able to work properly with the settin
         'F<$HOME/.ssh/ssh_config>',
         'C<-x>',
         'C<-X>'
-    );
+        );
     output '=back';
 
-    output '=head1 ', $self->loc('SUPPORT AND REPORTING BUGS');
-
+    output '=item *';
     output $self->loc(
-        q{A web site for comments, requests, bug reports and bug fixes/patches is available at: [_1]},
-        'L<https://github.com/duncs/clusterssh>'
-    );
-
-    output $self->loc(
-        q{If you require support, please run the following commands and create an issue via: [_1]},
-        'L<https://github.com/duncs/clusterssh/issues>',
+        q{If you require support, please run the following commands and post it on the web site in the support/problems forum:}
     );
     output 'C<< perl -V >>';
     output q{C<< perl -MTk -e 'print $Tk::VERSION,$/' >>};
@@ -1211,27 +1020,35 @@ This performs two tests to confirm cssh is able to work properly with the settin
         q{C<< perl -MX11::Protocol -e 'print $X11::Protocol::VERSION,$/' >>};
     output 'C<< cat /etc/csshrc $HOME/.clusterssh/config >>';
 
+    output '=item *';
     output $self->loc(
         q{Using the debug option (--debug) will turn on debugging output.  Repeat the option to increase the amount of debug.  However, if possible please only use this option with one host at a time, e.g. [_1] due to the amount of output produced (in both main and child windows).},
         'C<< cssh --debug <host> >>'
     );
+    output '=back';
 
     output '=head1 ', $self->loc('SEE ALSO');
     output $self->loc(
-        q{L<https://github.com/duncs/clusterssh/wiki/>,
+        q{L<http://clusterssh.sourceforge.net/>,
 C<ssh>,
 L<Tk::overview>,
 L<X11::Protocol>,
 C<perl>}
     );
 
+    output '=head1 ', $self->loc('CREDITS');
+    output $self->loc(
+        'A web site for comments, requests, bug reports and bug fixes/patches is available at: [_1]',
+        'L<https://github.com/duncs/clusterssh>'
+    );
+
     output '=head1 ', $self->loc('AUTHOR');
     output 'Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>';
 
     output '=head1 ', $self->loc('LICENSE AND COPYRIGHT');
     output $self->loc(
         q{
-Copyright 1999-2018 Duncan Ferguson.
+Copyright 1999-2015 Duncan Ferguson.
 
 This program is free software; you can redistribute it and/or modify it under the terms of either: the GNU General Public License as published by the Free Software Foundation; or the Artistic License.
 
@@ -1244,6 +1061,20 @@ See http://dev.perl.org/licenses/ for more information.
 
 1;
 
+__DATA__
+
+=pod
+
+=head1 NAME
+
+App::ClusterSSH::Getopt - module to process command line args
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+Object representing application configuration
+
 =head1 METHODS
 
 =over 4
@@ -1258,17 +1089,17 @@ Add extra options into the allowed set for parsing from the command line
 
 =item $obj=ClusterSSH::Getopts->add_common_options ({ })
 
-Add common options used by most calling scripts into the allowed set for
+Add common options used by most calling scripts into the allowed set for 
 parsing from the command line
 
 =item $obj=ClusterSSH::Getopts->add_common_session_options ({ })
 
-Add common session options used by most calling scripts into the allowed
+Add common session options used by most calling scripts into the allowed 
 set for parsing from the command line
 
 =item $obj=ClusterSSH::Getopts->add_common_ssh_options ({ })
 
-Add common ssh options used by most calling scripts into the allowed
+Add common ssh options used by most calling scripts into the allowed 
 set for parsing from the command line
 
 =item $obj->getopts
@@ -1287,3 +1118,21 @@ Simple helper func to print out pod lines with double returns
 Functions to output help and usage instructions
 
 =back
+
+=head1 AUTHOR
+
+Duncan Ferguson, C<< <duncan_j_ferguson at yahoo.co.uk> >>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 1999-2015 Duncan Ferguson.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
+
+1;
